@@ -1,5 +1,5 @@
 package Image::SVG::Transform;
-$Image::SVG::Transform::VERSION = '0.03';
+$Image::SVG::Transform::VERSION = '0.04';
 
 
 use strict;
@@ -11,7 +11,7 @@ Image::SVG::Transform - read the "transform" attribute of an SVG element
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -91,7 +91,7 @@ has ctm => (
         my $idx = 1;
         while ($idx < scalar @{ $self->transforms }) {
             my $matrix = $self->_generate_matrix($idx);
-            my $product = $matrix->multiply($ctm);
+            my $product = $ctm->multiply($matrix);
             $ctm = $product;
             $idx++;
         }
@@ -274,22 +274,13 @@ sub _generate_matrix {
             [ 0,   0,   1, ],
         );
     }
-    elsif ($t->{type} eq 'scale') {
-        my $sx = $t->{params}->[0];
-        my $sy = defined $t->{params}->[1] ? $t->{params}->[1] : $sx;
-        @matrix = (
-            [ $sx, 0,   0, ],
-            [ 0,   $sy, 0, ],
-            [ 0,   0,   1, ],
-        );
-    }
     elsif ($t->{type} eq 'rotate') {
         my $angle = deg2rad($t->{params}->[0]);
         my $cosa  = cos $angle;
         my $sina  = sin $angle;
         @matrix = (
             [ $cosa, -1*$sina,  0, ],
-            [ $sina,    $sina,  0, ],
+            [ $sina,    $cosa,  0, ],
             [ 0,            0,  1, ],
         );
     }
